import React, {useEffect} from "react";
import {Card, Col, Row, Table, Typography} from "antd";
import {BreadcumbComponent} from "../../component/BreadcumbComponent";
import {LINKS} from "../../routes/app";
import {useStore} from "../../utils/useStore";
import {observer} from "mobx-react-lite";

const {Title, Text} = Typography;

export const Profile = observer(() => {
    const store = useStore();
    const routeData = [
        {
            route: LINKS.HOME,
            name: "Home",
        },
        {
            route: LINKS.PROFILE,
            name: <span style={{fontWeight: 'bold'}}>Profile</span>,
        },
    ];

    useEffect(() => {
        (async () => {
            await Promise.allSettled([
                store.authentication.getProfile(),
                store.transaction.getDataHistoryTransaction(),
            ]);
        })()
    }, []);

    const columns = [
        {
            title: 'Markup Price',
            dataIndex: 'mark_up_price',
            key: 'mark_up_price',
            width: '20%',
        },
        {
            title: 'Name',
            dataIndex: 'name',
            key: 'name',
            width: '50%',
        },
        {
            title: 'Transaction Date',
            dataIndex: 'created_at',
            key: 'created_at',
        },
    ]

    return (
        <div className={["ppob-container"].join(" ")}>
            <BreadcumbComponent data={routeData}/>
            <Card>
                <Row style={{marginBottom: 20}}>
                    <Col span={24}>
                        <div>
                            <Title strong>Profile</Title>
                            {/*<Row>*/}
                            {/*    <Col span={10}>*/}
                            {/*        <Text strong>Name</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={14}>*/}
                            {/*        <Text>{store.authentication.profileData.username}</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={10}>*/}
                            {/*        <Text strong>Role</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={14}>*/}
                            {/*        <Text>{store.authentication.profileData.roles.name}</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={10}>*/}
                            {/*        <Text strong>Superior</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={14}>*/}
                            {/*        <Text>{store.authentication.profileData.superior.username}</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={10}>*/}
                            {/*        <Text strong>Wallet</Text>*/}
                            {/*    </Col>*/}
                            {/*    <Col span={14}>*/}
                            {/*        <Text>{store.authentication.profileData.wallet}</Text>*/}
                            {/*    </Col>*/}
                            {/*</Row>*/}
                        </div>
                    </Col>
                </Row>
                <Row>
                    <Col span={24}>
                        <div>
                            <Title strong level={3}>History User Transaction</Title>
                            <Table
                                columns={columns}
                                dataSource={store.transaction.dataHistoryTransaction}
                                bordered
                            />
                        </div>
                    </Col>
                </Row>
                <div/>
            </Card>
        </div>
    )
});
